<?php
$lang['delete'] = 'Slett';
$lang['cd_company'] = 'Company Directory firma';
$lang['dflt_urlprefix'] = 'Standard URL-prefiks for brukervennlige URLer';
$lang['dflt_alldayevent'] = 'Nye begivenheter er &quot;Hele dagen&quot; begivenheter som standard';
$lang['dflt_starttime'] = 'Standard starttid for nye begivenheter';
$lang['info_dflt_starttime'] = '<em>(kun gyldig om nye begivenheter ikke er &quot;Hele dagen&quot; begivenheter.)</em>';
$lang['search_type'] = 'S&oslash;ketype';
$lang['search_any'] = 'Vis resultater som passer hvilket som helst ord';
$lang['search_all'] = 'Vis resultater som passer alle ordene';
$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Merk:</span> &quot;Filopplastingsfelt&quot; er ikke s&oslash;kbare. &Aring; klikke p&aring; avkrysningsboks for andre felter vil ikke ha effekt.';
$lang['searchable'] = 'S&oslash;kbar';
$lang['help_param_editeventtemplate'] = 'Gjelder kun til myevents handlingen, denne parameteren kan angi en ikke standard &#039;rediger begivenhet&#039; mal som skal brukes n&aring;r en bruker oppretter eller redigerer en begivenhet';
$lang['help_param_editpage'] = 'Gjelder kun til myevents handlingen, denne parameteren kan angi en annen side for redigerings skjemaet.';
$lang['help_param_myeventstemplate'] = 'Gjelder kun til myevents handlingen, denne parameteren kan angi en ikke standard mal &aring; benytte';
$lang['cal_edit_event'] = 'Rediger Kalenderbegivenhet';
$lang['error_dberror'] = 'Datasefeil';
$lang['submit'] = 'Lagre';
$lang['info_sysdflt_editevent_template'] = 'Systemstandard &quot;Rediger begivenhet&quot; mal';
$lang['info_sysdflt_myevents_template'] = 'Systemstandard &quot;Mine begivenheter&quot; mal';
$lang['prompt_feedit_group'] = 'Medlemmer av denne FEU-gruppe kan legge til begivenheter';
$lang['prompt_feedit_page'] = 'Standard side for frontend redigeringskjema';
$lang['none'] = 'Ingen';
$lang['owner'] = 'Eier';
$lang['cal_editevent_templates'] = 'Rediger Begivehetskjema maler';
$lang['info_editevent_template_tab'] = 'Listen med maler som er tilgjengelige for &quot;Rediger handelse&quot; skjema';
$lang['editeventtemplate_addedit'] = 'Legg til/rediger en &quot;Rediger begivenhet&quot; skjemamal';
$lang['cal_myevents_templates'] = '&quot;Mine Begivenheter&quot; listemaler';
$lang['info_myevents_template_tab'] = 'Listen med maler som er tilgjengelige for &aring; vise en liste med brukerbegivenheter';
$lang['myeventstemplate_addedit'] = 'Legg til/rediger en &quot;Mine begivenheter&quot; rapportmal';
$lang['areyousure_removeconflicting'] = 'Denne handlingen vil fjerne eventuelle begivenheter som er i konflikt med begivenheter som ikke skal v&aelig;re overlappende. Er du sikker p&aring; at du vil gj&oslash;re dette?';
$lang['filter_conflicting'] = 'Filtrer motstridende begivenheter';
$lang['overlap_action_remove'] = 'Fjern motstridende begivenheter stille';
$lang['overlap_action_error'] = 'Vis en feilmelding';
$lang['prompt_overlap_action'] = 'Hva b&oslash;r skje n&aring;r en konflikt oppdages under redigering eller under opprettelse av en begivenhet';
$lang['error_event_conflict'] = 'Begivenhetsverdiene angitt overlapper med en eksisterende begivenhet som ikke tillater konflikter';
$lang['cal_info_overlap'] = 'Gjelder bare for begivenheter med en sluttid (eller hele dagen begivenheter)';
$lang['cal_overlap'] = 'Tillat nye arrangementer for &aring; overlappe med denne';
$lang['prompt_overlap_policy'] = 'Begivenhet overlappingsregler';
$lang['policy_all'] = 'Alle begivenheter kan overlappe';
$lang['policy_none'] = 'Ingen begivenheter kan overlappe';
$lang['policy_individual'] = 'Bestemt ved hver begivenhet';
$lang['lbl_back'] = 'Tilbake';
$lang['lbl_templates'] = 'Maler';
$lang['textarea'] = 'Tekstomr&aring;de';
$lang['error_calendar_incompatible'] = 'Vi har oppdaget at calendar modulen er installert ogs&aring;... Denne modulen er ikke kompatibel med calendar modulen og kan ikke v&aelig;re installert p&aring; samme nettsted. Vennligst avinstaller Calendar modulen';
$lang['error_event_not_found'] = 'Enten er ikke event_id i databasen, eller s&aring; er det mer enn en begivenhet med denne id! (%d)';
$lang['first_page'] = '<< ';
$lang['prev_page'] = '< ';
$lang['next_page'] = ' >';
$lang['last_page'] = ' >>';
$lang['page_of'] = 'Side %d av %d';
$lang['search_results'] = 'Kalender s&oslash;keresultater';
$lang['search_words'] = 'S&oslash;keord';
$lang['no_results_found'] = 'Ingen funn for sp&oslash;rringen du anga';
$lang['frequency'] = 'Hyppighet';
$lang['specified_date'] = 'Bruk den spesifiserte dato';
$lang['first_sunday'] = 'F&oslash;rste s&oslash;ndag i m&aring;neden';
$lang['first_monday'] = 'f&oslash;rste mandag i m&aring;neden';
$lang['first_tuesday'] = 'F&oslash;rste tirsdag i m&aring;neden';
$lang['first_wednesday'] = 'f&oslash;rste onsdag i m&aring;neden';
$lang['first_thursday'] = 'F&oslash;rste torsdag i m&aring;neden';
$lang['first_friday'] = 'F&oslash;rste fredag i m&aring;neden';
$lang['first_saturday'] = 'f&oslash;rste l&oslash;rdag i m&aring;neden';
$lang['second_sunday'] = 'Andre s&oslash;ndag i m&aring;neden';
$lang['second_monday'] = 'Andre mandag i m&aring;neden';
$lang['second_tuesday'] = 'Andre tirsdag i m&aring;neden';
$lang['second_wednesday'] = 'Andre onsdag i m&aring;neden';
$lang['second_thursday'] = 'Andre torsdag i m&aring;neden';
$lang['second_friday'] = 'Andre fredag i m&aring;neden';
$lang['second_saturday'] = 'Andre l&oslash;rdag i m&aring;neden';
$lang['third_sunday'] = 'Tredje s&oslash;ndag i m&aring;neden';
$lang['third_monday'] = 'Tredje mandag i m&aring;neden';
$lang['third_tuesday'] = 'Tredje tirsdag i m&aring;neden';
$lang['third_wednesday'] = 'Tredje onsdag i m&aring;neden';
$lang['third_thursday'] = 'Tredje torsdag i m&aring;neden';
$lang['third_friday'] = 'Tredje fredag i m&aring;neden';
$lang['third_saturday'] = 'tredje l&oslash;rdag i m&aring;neden';
$lang['fourth_sunday'] = 'Fjerde s&oslash;ndag i m&aring;neden';
$lang['fourth_monday'] = 'Fjerde mandag i m&aring;neden';
$lang['fourth_tuesday'] = 'Fjerde tirsdag i m&aring;neden';
$lang['fourth_wednesday'] = 'Fjerde onsdag i m&aring;neden';
$lang['fourth_thursday'] = 'Fjerde torsdag i m&aring;neden';
$lang['fourth_friday'] = 'Fjerde fredag i m&aring;neden';
$lang['fourth_saturday'] = 'Fjerde l&oslash;rdag i m&aring;neden';
$lang['last_sunday'] = 'Siste s&oslash;ndag i m&aring;neden';
$lang['last_monday'] = 'Siste mandag i m&aring;neden';
$lang['last_tuesday'] = 'Siste tirsdag i m&aring;neden';
$lang['last_wednesday'] = 'Siste onsdag i m&aring;neden';
$lang['last_thursday'] = 'Siste torsdag i m&aring;neden';
$lang['last_friday'] = 'Siste fredag i m&aring;neden';
$lang['last_saturday'] = 'Siste l&oslash;rdag i m&aring;neden';
$lang['error_invalid_recur_monthly_freq'] = 'Ugyldig hyppighet.... du kan ikke spesifisere b&aring;de en spesifikk dato OG andre valg';
$lang['searchresulttemplate_addedit'] = 'Legg til/rediger en s&oslash;keresultat mal';
$lang['info_searchresult_template_tab'] = 'Listen med maler som er tilgjengelig for s&oslash;keresultat visningen';
$lang['info_sysdflt_searchresult_template'] = 'Systemstandard s&oslash;keresultat mal';
$lang['cal_search_result_templates'] = 'S&oslash;keresultat maler';
$lang['error_query_failed'] = 'Databasesp&oslash;rring feilet';
$lang['error_search_invalid_dates'] = '*Ugyldige s&oslash;kedatoer spesifisert';
$lang['text'] = 'Tekst';
$lang['search'] = 'S&oslash;k';
$lang['category'] = 'Kategori';
$lang['info_sysdflt_search_template'] = 'Systemstandard s&oslash;keskjeme mal';
$lang['searchtemplate_addedit'] = 'Legg til/rediger s&oslash;keskjema mal';
$lang['info_search_template_tab'] = 'Listen med maler som er tilgjengelig for s&oslash;keskjemaet';
$lang['cal_search_form_templates'] = 'S&oslash;keskjema maler';
$lang['max'] = 'maks';
$lang['times'] = 'ganger';
$lang['on'] = 'p&aring;';
$lang['areyousure_uninstall'] = 'Er du sikker p&aring; at du vil gj&oslash;re dette? &Aring; fortsette vil permanent slette all data assosiert med denne modulen.';
$lang['post_uninstall'] = 'Calendar modulen har blitt avinstallert og all begivenhet- og malinformasjon assosiert med denne modulen har blitt fjernet';
$lang['fieldupdated'] = 'Felt oppdatert';
$lang['every'] = 'Hver';
$lang['or'] = 'eller';
$lang['update_children'] = 'Oppdater underliggende begivenheter';
$lang['error_nocategory'] = 'Du m&aring; velge minst en kategori';
$lang['error_nothingselected'] = 'Ingenting er valgt for sletting';
$lang['error_eventoverlap'] = 'Gjentatt begivenhet parameterne du har oppgitt vil resultere i overlappende begivenheter.';
$lang['recurs'] = 'Gjentas';
$lang['error_invalid_dates'] = 'En eller flere av datoverdiene som eer oppgitt var ikke gyldig';
$lang['sunday'] = 'S&oslash;ndag';
$lang['monday'] = 'Mandag';
$lang['tuesday'] = 'Tirsdag';
$lang['wednesday'] = 'Onsdag';
$lang['thursday'] = 'Torsdag';
$lang['friday'] = 'Fredag';
$lang['saturday'] = 'L&oslash;rdag';
$lang['abbr_sunday'] = 'S&oslash;';
$lang['abbr_monday'] = 'Ma';
$lang['abbr_tuesday'] = 'Ti';
$lang['abbr_wednesday'] = 'On';
$lang['abbr_thursday'] = 'To';
$lang['abbr_friday'] = 'Fr ';
$lang['abbr_saturday'] = 'L&oslash;';
$lang['weekdays'] = 'Ukedager';
$lang['plural_daily'] = 'Dager';
$lang['plural_weekly'] = 'Uker';
$lang['plural_monthly'] = 'M&aring;neder';
$lang['plural_yearly'] = '&Aring;r';
$lang['no'] = 'Nei';
$lang['daily'] = 'Daglig';
$lang['weekly'] = 'Ukentlig';
$lang['monthly'] = 'M&aring;nedlig';
$lang['yearly'] = '&Aring;rlig';
$lang['interval'] = 'Gjenta hver';
$lang['cal_recur_details'] = 'Gjentakende begivenhetsdetaljer';
$lang['unlimited'] = 'Ubegrenset';
$lang['max_recur_events'] = 'Maksimalt antall underliggende begivenheter';
$lang['use_to_date'] = 'Spesifiser en annen sluttdato?';
$lang['cancel'] = 'Avbryt';
$lang['show_child_events'] = 'Vis under-begivenhet';
$lang['n/a'] = 'i/t';
$lang['recurs_until'] = 'Gjenta inntil';
$lang['parent'] = 'Overordnet';
$lang['recur_period'] = 'Gjentakelsesperiode';
$lang['filter'] = 'Filtrer';
$lang['start_date'] = 'Startdato';
$lang['end_date'] = 'Suttdato';
$lang['info_upcominglist_template_tab'] = 'Listen med maler som er tilgjengelige for upcominglist(kommende begivenhetersliste) visning';
$lang['upcominglisttemplate_addedit'] = 'Legg til/rediger Upcominglist(kommende begivenhetersliste) visningsmal';
$lang['info_sysdflt_upcominglist_template'] = 'Systemstandard Upcominglist(kommende begivenhetersliste) mal';
$lang['info_list_template_tab'] = 'Listen med maler som er tilgjengelige for listevisninger';
$lang['listtemplate_addedit'] = 'Legg til/rediger en Listevisningsmal';
$lang['info_sysdflt_list_template'] = 'Systemstandard Listevisningsmal';
$lang['info_event_template_tab'] = 'Listen med maler som er tilgjengelige for Begivenhetsvisninger';
$lang['eventtemplate_addedit'] = 'Legg til/rediger en Begivenhetsvisningsmal';
$lang['info_sysdflt_event_template'] = 'Systemstandard  Begivenhetsmal';
$lang['info_calendar_template_tab'] = 'Listen med maler som er tilgjengelige for kalendervisninger';
$lang['calendartemplate_addedit'] = 'Legg til/rediger en Kalendervisningsmal';
$lang['info_sysdflt_calendar_template'] = 'Systemstandard Kalendermal';
$lang['info_sysdflt_template'] = 'Dette skjema definerer malen som vil bli benyttet n&aring;r du klikker &quot;Ny mal&quot; i den aktuelle fanen. &Aring; endre noe her vil ikke ha noen umiddelbar effekt p&aring; visninger generert fra denne modulen.';
$lang['eventdesc-EventAdded'] = 'Kallt etter en kalenderbegivenhet legges til';
$lang['eventdesc-EventEdited'] = 'Kallt etter en kallenderbegivenhet er redigert';
$lang['eventdesc-EventDeleted'] = 'Kallt etter en begivenhet har blitt slettet';
$lang['eventdesc-CategoryAdded'] = 'Kallt etter en kategori er opprettet';
$lang['eventdesc-CategoryEdited'] = 'Kallt etter en kategori er redigert';
$lang['eventdesc-CategoryDeleted'] = 'Kallt etter en kategori er slettet';
$lang['eventhelp-EventAdded'] = '<p>Sendt n&aring;r en kalenderbegivenhet er lagt til.</p>
<h4>Parametere</h4>
<ul>
<li>\&quot;event_title\&quot; - Begivenhets Tittel</li>
<li>\&quot;event_summary\&quot; - Sammendrag tekst</li>
<li>\&quot;event_details\&quot; - Detaljert beskrivelse</li>
<li>\&quot;event_date_start\&quot; - Begivenhetens start dato/tid</li>
<li>\&quot;event_date_end\&quot; - Begivenhetens slutt dato/tid</li>
<li>\&quot;event_created_by\&quot; - BrukerIDen for opphavsmannen</li>
<li>\&quot;event_id\&quot; - Begivenhetens ID</li>
</ul>
';
$lang['eventhelp-EventEdited'] = '<p>Sendt n&aring;r en kalenderbegivenhet er redigert.</p>
<h4>Parametere</h4>
<ul>
<li>\&quot;event_title\&quot; - Begivenhets tittel</li>
<li>\&quot;event_summary\&quot; - Sammendrag tekst</li>
<li>\&quot;event_details\&quot; - Detaljert beskrivelse</li>
<li>\&quot;event_date_start\&quot; - Begivenhetens start dato/tid</li>
<li>\&quot;event_date_end\&quot; - Begivenhetens slutt dato/tid</li>
<li>\&quot;event_created_by\&quot; - BrukerIDen for opphavsmannen</li>
<li>\&quot;event_id\&quot; - Begivenhetens ID</li>
</ul>
';
$lang['eventhelp-EventDeleted'] = '<p>Sendt n&aring;r en kalenderbegivenhet er slettet.</p>
<h4>Parametere</h4>
<ul>
<li>\&quot;event_id\&quot; - Begivenhetens ID</li>
</ul>
';
$lang['eventhelp-CategoryAdded'] = '<p>Sendt n&aring;r en kalender kategori er lagt til.</p>
<h4>Parametere</h4>
<ul>
<li>\&quot;category_id\&quot; - Kategori IDen</li>
</ul>
';
$lang['eventhelp-CategoryEdited'] = '<p>Sendt n&aring;r en kalender kategori er redigert.</p>
<h4>Parametere</h4>
<ul>
<li>\&quot;category_id\&quot; - Kategori IDen</li>
<li>\&quot;category_name\&quot; - Kategori navnet</li>
<li>\&quot;category_order\&quot; - Kategori sorteringsrekkef&oslash;lgen</li>
</ul>
';
$lang['eventhelp-CategoryDeleted'] = '<p>Sendt n&aring;r en kalender kategori er slettet.</p>
<h4>Parametere</h4>
<ul>
<li>\&quot;category_id\&quot; - Kategori IDen</li>
<li>\&quot;category_name\&quot; - Kategori navnet</li>
<li>\&quot;category_order\&quot; - Kategori sorteringsrekkef&oslash;lgen</li>
</ul>
';
$lang['msg_eventadded'] = 'Begivenhet lagt til';
$lang['error_noeventname'] = 'Et navn p&aring; begivenheten er p&aring;krevd';
$lang['error_noupload'] = 'FEIL: Ingen opplastet fil funnet';
$lang['error_invalidfilename'] = 'FEIL: Den opplastede filen kan ikke aksepteres';
$lang['error_problemwithupload'] = 'FEIL: Et problem oppstod under fors&oslash;k p&aring; &aring; laste opp filen';
$lang['error_filecopyfailed'] = 'FEIL: Et problem oppstod under kopiering av fila til sin m&aring;lplassering';
$lang['error_fileexists'] = 'FEIL: En fil med dette navnet eksisterer allerede';
$lang['error_csvfilenotfound'] = 'FEIL: Kunne ikke finne CSV Filen';
$lang['error_cantopenfile'] = 'FEIL: Kan ikke &aring;pne filen';
$lang['error_categoryexists'] = 'ERROR: En kategori med navnet %s eksisterer allerede';
$lang['cal_id'] = 'ID';
$lang['cal_calendar'] = 'Calguys Kalender';
$lang['cal_default_templates'] = 'Standard maler';
$lang['cal_description'] = 'En fleksibel modul med mange egenskaper som tillater visning av informasjon om begivenheter p&aring; mange forskjellige m&aring;ter.';
$lang['cal_addevent'] = 'Legg til begivenhet';
$lang['cal_import_events'] = 'Import begivenheter';
$lang['cal_events'] = 'Begivenheter';
$lang['cal_categories'] = 'Kategorier';
$lang['cal_calendar_template'] = 'Mal for kalender';
$lang['cal_list_template'] = 'Mal for listevisning';
$lang['cal_upcominglist_template'] = 'Mal for forest&aring;ende begivenheter';
$lang['cal_event_template'] = 'Mal for begivenheter';
$lang['cal_settings'] = 'Konfigurasjon';
$lang['cal_prev'] = '&laquo; Forrige';
$lang['cal_next'] = 'Neste &raquo;';
$lang['cal_categories_updated'] = 'Kategorier er oppdatert';
$lang['cal_settings_updated'] = 'Konfigurasjon er oppdatert';
$lang['cal_add_event'] = 'Legg til begivenhet';
$lang['cal_edit'] = 'Endre';
$lang['cal_delete'] = 'Slett';
$lang['cal_areyousure'] = '&Oslash;nsker du virkelig &aring; slette';
$lang['cal_update_template'] = 'Oppdater mal';
$lang['cal_sunday'] = 'S&oslash;ndag';
$lang['cal_monday'] = 'Mandag';
$lang['cal_tuesday'] = 'Tirsdag';
$lang['cal_wednesday'] = 'Onsdag';
$lang['cal_thursday'] = 'Torsdag';
$lang['cal_friday'] = 'Fredag';
$lang['cal_saturday'] = 'L&oslash;rdag';
$lang['cal_sun'] = 'S&oslash;n';
$lang['cal_mon'] = 'Man';
$lang['cal_tues'] = 'Tir';
$lang['cal_wed'] = 'Ons';
$lang['cal_thurs'] = 'Tor';
$lang['cal_fri'] = 'Fre';
$lang['cal_sat'] = 'L&oslash;r';
$lang['cal_january'] = 'Januar';
$lang['cal_february'] = 'Februar';
$lang['cal_march'] = 'Mars';
$lang['cal_april'] = 'April ';
$lang['cal_may'] = 'Mai';
$lang['cal_june'] = 'Juni';
$lang['cal_july'] = 'Juli';
$lang['cal_august'] = 'August ';
$lang['cal_september'] = 'September ';
$lang['cal_october'] = 'Oktober';
$lang['cal_november'] = 'November ';
$lang['cal_december'] = 'Desember';
$lang['cal_add'] = 'Legg til';
$lang['cal_update'] = 'Lagre og lukk';
$lang['cal_event'] = 'Begivenhet';
$lang['cal_date'] = 'Dato';
$lang['cal_summary'] = 'Sammendrag';
$lang['cal_details'] = 'Detaljer';
$lang['cal_more'] = 'mer >>';
$lang['cal_return'] = 'Tilbake';
$lang['cal_to'] = 'til';
$lang['cal_past_events'] = 'Gamle begivenheter';
$lang['cal_upcoming_events'] = 'Kommende begivenheter';
$lang['cal_any_category'] = 'Alle kategorier';
$lang['cal_show_only_events_in'] = 'Vis bare begivenheter i ';
$lang['cal_filter_by'] = 'Filtrer med';
$lang['cal_go'] = 'OK';
$lang['cal_title'] = 'Tittel';
$lang['cal_fromdate'] = 'Fra dato';
$lang['cal_todate'] = 'Til dato';
$lang['cal_update_categories'] = 'Oppdater kategorier';
$lang['cal_language'] = 'Spr&aring;k';
$lang['cal_updatesettings'] = 'Oppdater innstillinger';
$lang['cal_use_twelve_hour_clock'] = 'Bruk tolv-timers klokke for time nedtrekk?';
$lang['cal_default_category'] = 'Standard Kategori';
$lang['cal_update_fields'] = 'Oppdater felter';
$lang['force_category'] = 'Krev minst en kategori';
$lang['showpastyears'] = 'Hvor mange historiske &aring;r er tillatt';
$lang['showfutureyears'] = 'Hvor mange fremtidige &aring;r er tillatt';
$lang['hidesummary'] = 'Skal sammendrag-feltet v&aelig;re skjult';
$lang['hidecontent'] = 'Skal innhold-feltet v&aelig;re skjult';
$lang['category_reminder'] = 'Vennligst velg en eller flere kategorier for denne begivenhet';
$lang['module_example_stylesheet'] = 'Kalender CSS eksempel';
$lang['error_permission'] = 'Du trenger n&oslash;dvendig tillatelse (%s) for &aring; f&aring; tilgang til denne funksjonen';
$lang['install_postmessage'] = 'Husk &aring; sette &quot;Modify Calendar&quot; tillatelse for brukere som skal administrere Kalender begivenheter.';
$lang['deletetagged'] = 'Slett merkede begivenheter';
$lang['confirmdeletetagged'] = 'Er du sikker p&aring; at disse begivenheter skal slettes?';
$lang['taggeddeleted'] = 'Merkede begivenheter ble slettet';
$lang['templates'] = 'Maler';
$lang['template_help'] = 'Mal Hjelp';
$lang['file_templates'] = 'Fil Maler';
$lang['addtemplate'] = 'Legg til mal';
$lang['template'] = 'Mal';
$lang['templatenametext'] = 'Malnavn';
$lang['edittemplate'] = 'Rediger mal';
$lang['deletetemplate'] = 'Slett mal';
$lang['newtemplate'] = 'Nytt malnavn';
$lang['templatenameexists'] = 'Feil: En mal med det navnet eksisterer allerede. Vennligst velg et annet navn.';
$lang['templateimported'] = 'En mal ble vellykket importert til databasen og er n&aring; installert for bruk.';
$lang['view_default_stylesheet'] = 'Vis Standard stilark';
$lang['filename'] = 'Filnavn';
$lang['importtemplate'] = 'Importer mal';
$lang['template_deleted'] = 'Malen ble slettet fra databasen.';
$lang['updatetemplatesuccess'] = 'Malen ble vellykket oppdatert';
$lang['updatetemplatefailure'] = 'En feil oppstod under oppdatering av malen';
$lang['settingssaved'] = 'Innstillingene ble lagret';
$lang['categorydeleted'] = 'Kategori slettet';
$lang['categoryupdated'] = 'Kategori oppdatert';
$lang['categoryadded'] = 'Kategori lagt til';
$lang['eventdeleted'] = 'Begivenheten ble slettet';
$lang['eventupdated'] = 'Begivenheten ble oppdatert';
$lang['default_page_error'] = 'Feil: Du m&aring; sette en standard side for &aring; kunne benytte Kalender med vakre URLer aktivert. Vennligst g&aring; til Kalender innstillinger og velg en side.';
$lang['time_at'] = 'p&aring;';
$lang['type'] = 'Type ';
$lang['name'] = 'Navn';
$lang['order'] = 'Sorter';
$lang['fieldadded'] = 'Feltet ble lagt til';
$lang['fielddeleted'] = 'Felt slettet';
$lang['fields'] = 'Ekstrafelter(Custom fields)';
$lang['textfield'] = 'Tekstfelt';
$lang['uploadfield'] = 'Filopplastingsfelt';
$lang['description'] = '<p>Kalender(CGCalendar) er en modul for visning av begivenheter p&aring; din nettside. N&aring;r modulen er installert blir en administrasjonside for Kalender lagt til innholdsmenyen som vil tillate deg &aring; administrere dine begivenheter.</p>';
$lang['defaultcalendarpage'] = 'Standard side som inneholder Kalender. Denne siden m&aring; inneholde en Smarty tagg som kaller opp Kalender. Dette er krevd om du benytter vakre URLer.';
$lang['uploaddirectory'] = 'Katalog hvor filopplastinger skal plasseres';
$lang['uploadfiletypes'] = 'Tillatte filtyper';
$lang['uploadunique'] = 'Sjekk for unike filnavn';
$lang['thumb_width'] = 'Miniatyrbilde bredde';
$lang['thumb_height'] = 'Miniatyrbilde h&oslash;yde';
$lang['large_width'] = 'Stort bilde bredde';
$lang['large_height'] = 'Stort bilde h&oslash;yde';
$lang['cal_recur_period'] = 'gjentas';
$lang['cal_recur_until'] = 'Gjentas inntil';
$lang['help_template'] = '<p><b>Skriv Opphavsmann navn:</b></p>
<code>Opphavsmann: {$event.authorname}</code>
';
$lang['cal_help'] = '<h3>Notice:</h3>
<p>Version 1.0 of the Calguy Calendar module is a complete fork of the old calendar module.  However, this module is not compatible in any way with the other module.</p>
<h3>What does this do?</h3>
<p>Calguys Calendar is a module for displaying events on your page. When the
module is installed, a &amp;quot;Calguys Calendar&amp;quot; admin page is added to the plugins menu
that will allow you to manage your events.</p>
<h3>Security</h3>
<p>The user must belong to a group with the &#039;Modify Calendar&#039; permission
in order to add, edit, or delete calendar event entries.</p>
<h3>How do I use it?</h3>
<ol>
  <li>Put the cms_module tag in the page content. Make sure it is not enclosed in &amp;lt;pre&amp;gt;...&amp;lt;/pre&amp;gt; tags.  You will need to view source code for this.  The code would look something like:<br />
  <tt>{cms_module module=&quot;CGCalendar&quot;}</tt><br />
  <li>Style the calendar appropriately for your display (an example stylesheet is provided for this purpose)</li>
</ol>
<br/>
<p><b>To attach the sample stylesheet to your template:</b></p>
<ol>
<li>Go to &quot;Layout -> Templates&quot;</li>
<li>Click the CSS icon (Attach Stylesheet to Template) button to the right of your template</li>
<li>Choose &quot;Calguys Calendar CSS example&quot; from the drop-down menu.</li>
<li>Click the &quot;Add a Stylesheet&quot; button.</li>
</ol>
<br/>
<h3>Parameters</h3>
<table border=0 cellpadding=3 cellspacing=0>
  <tr>
     <td>action</td>
     <td>Acceptable values:<br>
        &quot;default&quot; - Specifies the default action, works in conjunction with the &quot;display&quot; parameter below.<br/>
	&quot;search&quot; - Display a form for advanced searching of calendar events.<br/>
        &quot;myevents&quot; - Display a list of all of a users events, and allow adding, editing or deleting those events<br/>
        &quot;addedit_event&quot; - Display a form allowing to add or edit a single event.;
     </td>
  </tr>

  <tr>
     <td>display</td>
     <td>Acceptable values:<br>
	 &quot;calendar&quot; - displays events for the current month in a traditional grid.  Inclues links to prev. and next months.<br/>
	 &quot;event&quot; - display a detail report for a specific event.  To use this display mode, the event_id parameter must be specified.<br/>
	 &quot;list&quot; - displays events for the current month as a list.  Includes links to prev. and next months.<br/>
	 &quot;yearlist&quot; - displays events for the current year in a list.  Includes links to prev. and next years.<br/>
	 &quot;pastlist&quot; - displays all past events.  No prev/next links.<br/>
	 &quot;upcominglist&quot; - displays all upcoming events.  No prev/next links.<br/>
		Defaults to &quot;calendar&quot; <em>(optional)</em>
     </td>
  </tr>

  <tr>
     <td>category</td>
     <td>Only display items for that category. Leaving unset, will show all categories. Note that
	 you can limit to multiple categories by separating each one with a comma.<em>(optional)</em></td>
  </tr>

  <tr>
     <td>month</td>
     <td>Display entries for a particular month. If year is not set, then the current year is
	 assumed. This option only works if display is set to &quot;list&quot; or &quot;calendar&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>year</td>
     <td>Display entries for a particular year.
	This option only works if display is set to &quot;list&quot; or &quot;calendar&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>limit</td>
     <td>Set to the maximum number of events to display. This option only works if display is set to &quot;list&quot;, &quot;pastlist&quot; or &quot;upcominglist&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>first_day_of_week</td>
     <td>Set to the first day of the week as a number between 0 and 6 (0 = Sunday). Default is 1 (Monday).
	 This option only works if display is set to &quot;calendar&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>use_session</td>
	 <td>Use session variables to store the specifications of the calendar. This will allow a calendar to remember its settings over numerous page views and while scrolling to different months.  In the search form it allows saving the search settings until the browser is reset.  Default is false.  If specified, the value should contain a unique identifier for that calendar instance.  This option only works if display is set to &quot;calendar&quot; or &quot;list&quot;, or if &quot;action&quot; is search. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>inline</td>
     <td>Set to 1 to set all of the event links to inlined mode (they will replace the oringal tag).  Default is 0. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>reverse</td>
     <td>Set to true to display events in reverse chronological order. Applicable to &quot;list&quot;, &quot;pastlist&quot; and &quot;upcominglist&quot; displays. Default is false. For the &quot;pastlist&quot;, reverse=true is assumed.<em>(optional)</em></td>
  </tr>

  <tr>
     <td>detailpage=&quot;pagealias&quot;</td>
     <td>Page to display Calendar event details in. This can either be a page alias or an id. Used to allow details to be displayed in a different template from the summary. Default is current page. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>columns</td>
     <td>Makes Calendar output only a subset of relevant events for allowing displaying in columns. Allowed values 1/2. Default is 1. Implemented for upcominglist and pastlist only. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>columnstyle</td>
     <td>If columns=2 this parameter sets whether the order of events in columns should be organized horizontally (0) or vertically (1). Default is 1. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>currentcolumn</td>
     <td>If columns=2 this indicated whether Calendar should display content of column 1 or 2. Allowed values 1/2. Default is 1. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>event_id</td>
     <td>Used with the display=event mode, this parameter allows you to display information about a specific event on demand.</td>
  </tr>

  <tr>
     <td>limit</td>
     <td>Used with the list displays, this parameter allows specifying a maximum number of events to display, and then provides pagination capabilities.</td>
  </tr>

  <tr>
     <td>calendartemplate</td>
     <td>Used with display=calendar, this parameter allows you to specify a non default calendar template.</td>
  </tr>

  <tr>
     <td>eventtemplate</td>
     <td>Used with display=event, or you can also specify this parameter on any Calendar module call, this parameter allows you to specify a non default event template.</td>
  </tr>

  <tr>
     <td>listtemplate</td>
     <td>Used with display=list, this parameter allows you to specify a non default list template.</td>
  </tr>

  <tr>
     <td>upcominglisttemplate</td>
     <td>Used with display=upcominglist, this parameter allows you to specify a non default upcominglist template.</td>
  </tr>

  <tr>
     <td>unique_only</td>
     <td>Used with display=upcominglist, and with action=search, this parameter allows you to specify that only one event of a certain type should be returned&#039;;
  </tr>

</table>

<h3>Custom Fields</h3>
<p>It is possible to define a number of custom fields to associate with each event using the Fields tab in the admin. Once one or more fields has been defined the values of that field for each event can be set using the events tab in the admin. These field values can be rendered using a template using the syntax event.fields.fieldname. Hint - insert {debug} into your template see all the data passed to the template.</p>

<h3>Examples</h3>
<h4>Example of allowing Comments on Calendar events</h4>
<p>Install the Comments module and put this in your Calendar &quot;Event Template&quot;:</p>
<pre>{cms_module module=&#039;comments&#039; modulename=&#039;CGCalendar&#039; pageid=$event.event_id}</pre>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>Discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['utma'] = '156861353.1900154316.1310459398.1310459398.1310459398.1';
$lang['utmz'] = '156861353.1310459398.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-1089425687-1306833892307';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>